@@ -256,8 +256,8 @@ void KcmSambaConf::init() {
   connect( _interface->removeSambaUserBtn, SIGNAL(clicked()),
           this, SLOT( removeSambaUserBtnClicked() ));
 
-  _interface->removeSambaUserBtn->setIconSet(SmallIcon("1rightarrow"));
-  _interface->addSambaUserBtn->setIconSet(SmallIcon("1leftarrow"));
+  _interface->removeSambaUserBtn->setIconSet(SmallIconSet("1rightarrow"));
+  _interface->addSambaUserBtn->setIconSet(SmallIconSet("1leftarrow"));
 
 
   connect( _interface->sambaUsersListView, SIGNAL(mouseButtonPressed(int,QListViewItem*,const QPoint &,int)),
@@ -615,6 +615,7 @@ void KcmSambaConf::loadBaseSettings(SambaShare* share)
   if ( s == "ads" ) i = 4;
 
   _interface->securityLevelBtnGrp->setButton(i);
+  _interface->updateSecurityLevelHelpLbl();
 
 }
 
@@ -1104,7 +1105,7 @@ void KcmSambaConf::joinADomainBtnClicked() {
       KMessageBox::sorry(0,i18n("Joining the domain %1 failed.").arg(dlg->domainEdit->text()));
     }
   }
-
+  delete dlg;
 }
 
 
