@@ -2,7 +2,7 @@
 *                               docking.cpp
 *                             -------------------
 *
-*    Revision     : $Id: docking.cpp 422087 2005-06-04 13:44:54Z pino $
+*    Revision     : $Id: docking.cpp 477049 2005-11-02 20:18:41Z uwolfer $
 *    begin        : Tue Jan 29 2002
 *    copyright    : (C) 2002 by Patrick Charbonnier
 *                 : Based On Caitoo v.0.7.3 (c) 1998 - 2000, Matej Koss
@@ -46,7 +46,9 @@ DockWidget::DockWidget(KMainWidget * _parent):KSystemTray(_parent)
 
     // popup menu for right mouse button
     KPopupMenu *popupMenu = contextMenu();
+    parent->action("paste_transfer")->plug(popupMenu);
     parent->action("drop_target")->plug(popupMenu);
+    parent->action("konqueror_integration")->plug(popupMenu);
     popupMenu->insertSeparator();
     parent->m_paPreferences->plug(popupMenu);
 
@@ -102,6 +104,12 @@ void DockWidget::updateToolTip( const QString& _status )
 }
 
 
+void DockWidget::changeIcon( const QString& icon )
+{
+    setPixmap( loadIcon( icon ));
+}
+
+
 DynamicTip::DynamicTip( QWidget * parent )
    : QToolTip( parent )
 {
