@@ -33,6 +33,7 @@
 #include <kiconloader.h>
 #include <kstandarddirs.h>
 #include <kwin.h>
+#include <kmessagebox.h>
 
 #include <assert.h>
 #include "safedelete.h"
@@ -101,7 +102,7 @@ void
 Transfer::init(const uint _id)
 {
     sDebugIn << endl;
-
+    remainingTimeSec = 0;
     totalSize = 0;
     processedSize = 0;
     percent = 0;
@@ -127,7 +128,7 @@ Transfer::init(const uint _id)
 
     m_paPause = new KAction(i18n("&Pause"), "tool_pause", 0, this, SLOT(slotRequestPause()), this, "pause");
 
-    m_paDelete = new KAction(i18n("&Delete"), "tool_delete", 0, this, SLOT(slotRequestRemove()), this, "delete");
+    m_paDelete = new KAction(i18n("&Delete"), "editdelete", 0, this, SLOT(slotRequestRemove()), this, "delete");
 
     m_paRestart = new KAction(i18n("Re&start"), "tool_restart", 0, this, SLOT(slotRequestRestart()), this, "restart");
 
@@ -258,7 +259,8 @@ void Transfer::setSpeed(unsigned long _speed)
     // sDebugIn <<endl;
     speed = _speed;
 
-    remainingTime = KIO::calculateRemaining(totalSize, processedSize, speed);
+    remainingTimeSec = KIO::calculateRemainingSeconds(totalSize, processedSize, speed);
+    remainingTime = KIO::convertSeconds(remainingTimeSec);
     //sDebugOut <<endl;
 }
 
@@ -450,10 +452,18 @@ void Transfer::slotRequestRestart()
 void Transfer::slotRequestRemove()
 {
     sDebugIn << endl;
+    if (dlgIndividual && !ksettings.b_expertMode)
+    {
+        if (KMessageBox::warningContinueCancel(0, i18n("Are you sure you want to delete this transfer?"),
+                                           QString::null, KStdGuiItem::del(),
+                                           QString("delete_transfer"))
+            != KMessageBox::Continue)
+            return;
+    }
     m_paDelete->setEnabled(false);
     m_paPause->setEnabled(false);
-    if(dlgIndividual)
-                dlgIndividual->close();
+    if (dlgIndividual)
+        dlgIndividual->close();
 
 
     if ( status != ST_FINISHED )
@@ -594,27 +604,32 @@ void Transfer::slotSpeed(unsigned long bytes_per_second)
     if (speed == 0 && status == ST_RUNNING) {
         setText(view->lv_speed, i18n("Stalled"));
         setText(view->lv_remaining, i18n("Stalled"));
+        if(dlgIndividual)
+            dlgIndividual->setSpeed(i18n("Stalled"));
     } else if (speed == 0 && status == ST_FINISHED) {
 
         setText(view->lv_progress, i18n("OK as in 'finished'","OK"));
-        setText(view->lv_speed, i18n("0 MB/s"));
-        setText(view->lv_remaining, i18n("00:00:00"));
+        setText(view->lv_speed, i18n("Finished"));
+        setText(view->lv_remaining, i18n("Finished"));
+        if(dlgIndividual)
+            dlgIndividual->setSpeed(i18n("Finished"));
 
     } else if (speed == 0 && status == ST_STOPPED) {
 
 
-        setText(view->lv_speed, i18n("0 MB/s"));
-        setText(view->lv_remaining, i18n("00:00:00"));
+        setText(view->lv_speed, i18n("Stopped"));
+        setText(view->lv_remaining, i18n("Stopped"));
+        if(dlgIndividual)
+            dlgIndividual->setSpeed(i18n("Stopped"));
 
     } else {
         QString tmps = i18n("%1/s").arg(KIO::convertSize(speed));
         setText(view->lv_speed, tmps);
-        setText(view->lv_remaining, remainingTime.toString());
+        setText(view->lv_remaining, remainingTime);
+        if(dlgIndividual)
+            dlgIndividual->setSpeed(tmps + " ( " + remainingTime  + " ) ");
     }
 
-	if(dlgIndividual)
-    	dlgIndividual->setSpeed(speed, remainingTime);
-
     //sDebugOut<<endl;
 }
 
