@@ -53,7 +53,7 @@ static NewsSourceBase::Data NewsSourceDefault[DEFAULT_NEWSSOURCES] = {
 		NewsSourceBase::Computers, 10, false, false ),
 		NewsSourceBase::Data(
 		QString::fromLatin1("KDE Deutschland"),
-		QString::fromLatin1("http://www.kde.de/news/news.rdf"),
+		QString::fromLatin1("http://www.kde.de/nachrichten/nachrichten.rdf"),
 		QString::fromLatin1("http://www.kde.de/favicon.ico"),
 		NewsSourceBase::Computers, 10, true, false, QString::fromLatin1("de")),
 		NewsSourceBase::Data(
@@ -222,8 +222,8 @@ static NewsSourceBase::Data NewsSourceDefault[DEFAULT_NEWSSOURCES] = {
 		QString::fromLatin1("http://www.amiga-news.de/favicon.ico"),
 		NewsSourceBase::Computers, 10, false, false),
 		NewsSourceBase::Data(
-		QString::fromLatin1("Linux4Us (sowie RadioTux & Magazin42)"),
-		QString::fromLatin1("http://www.linux4us.de/newsticker.fd"),
+		QString::fromLatin1("RadioTux)"),
+		QString::fromLatin1("http://blog.radiotux.de/feed/"),
 		QString::null,
 		NewsSourceBase::Computers, 10, false, false, QString::fromLatin1("de")),
 		NewsSourceBase::Data(
@@ -271,12 +271,28 @@ static NewsSourceBase::Data NewsSourceDefault[DEFAULT_NEWSSOURCES] = {
 		QString::fromLatin1("http://www.maximumbsd.com/backend/mb.rdf"),
 		QString::fromLatin1("http://www.maximumbsd.com/favicon.ico"),
 		NewsSourceBase::Computers, 10, false, false),
+		NewsSourceBase::Data(
+		QString::fromLatin1("BR-Linux.org"),
+		QString::fromLatin1("http://br-linux.org/noticias/index.rdf"),
+		QString::fromLatin1("http://br-linux.org/noticias/favicon.ico"),
+		NewsSourceBase::Computers, 10, false, false),
+		NewsSourceBase::Data(
+		QString::fromLatin1("OSNews.com"),
+		QString::fromLatin1("http://www.osnews.com/files/recent.rdf"),
+		QString::fromLatin1("http://www.osnews.com/favicon.ico"),
+		NewsSourceBase::Computers, 10, false, false),
 	// Miscellaneous ------
 		NewsSourceBase::Data(
 		QString::fromLatin1("tagesschau.de"),
 		QString::fromLatin1("http://www.tagesschau.de/newsticker.rdf"),
 		QString::fromLatin1("http://www.tagesschau.de/favicon.ico"),
 		NewsSourceBase::Misc, 10, true, false, QString::fromLatin1("de")),
+		NewsSourceBase::Data(
+		QString::fromLatin1("N24.de"),
+		QString::fromLatin1("http://www.n24.de/rss/?rubrik=home"),
+		QString::fromLatin1("http://www.n24.de/favicon.ico"),
+		NewsSourceBase::Misc, 10, true, false, QString::fromLatin1("de")),
+/*
 		NewsSourceBase::Data(
 		QString::fromLatin1("CNN"),
 		QString::fromLatin1("http://www.cnn.com/cnn.rss"),
@@ -287,6 +303,7 @@ static NewsSourceBase::Data NewsSourceDefault[DEFAULT_NEWSSOURCES] = {
 		QString::fromLatin1("http://europe.cnn.com/cnn.rss"),
 		QString::fromLatin1("http://europe.cnn.com/favicon.ico"),
 		NewsSourceBase::Misc, 10, false, false),
+*/
 		NewsSourceBase::Data(
 		QString::fromLatin1("HotWired"),
 		QString::fromLatin1("http://www.hotwired.com/webmonkey/meta/headlines.rdf"),
@@ -307,7 +324,17 @@ static NewsSourceBase::Data NewsSourceDefault[DEFAULT_NEWSSOURCES] = {
 		QString::fromLatin1("Revista do Linux"),
 		QString::fromLatin1("http://www.revistadolinux.com.br/noticias/arquivo/noticias.rdf"),
 		QString::fromLatin1("http://www.revistadolinux.com.br/favicon.ico"),
-		NewsSourceBase::Magazines, 10, false, false),	
+		NewsSourceBase::Magazines, 10, false, false /*, QString::fromLatin1("br")*/ ),
+		NewsSourceBase::Data(
+		QString::fromLatin1("Spiegel.de"),
+		QString::fromLatin1("http://www.spiegel.de/schlagzeilen/rss/0,5291,,00.xml"),
+		QString::fromLatin1("http://www.spiegel.de/favicon.ico"),
+		NewsSourceBase::Magazines, 10, true, false, QString::fromLatin1("de")),
+		NewsSourceBase::Data(
+		QString::fromLatin1("FAZ.de"),
+		QString::fromLatin1("http://www.faz.net/s/Rub/Tpl~Epartner~SRss_.xml"),
+		QString::fromLatin1("http://www.faz.net/favicon.ico"),
+		NewsSourceBase::Magazines, 10, true, false, QString::fromLatin1("de")),
 	// Recreation
 		NewsSourceBase::Data(
 		QString::fromLatin1("Segfault"),
@@ -353,11 +380,11 @@ bool ArticleFilter::matches(Article::Ptr a) const
 
 	if (condition() == i18n("contain"))
 		matches = a->headline().contains(expression());
-	else if (condition() == i18n("don't contain"))
+	else if (condition() == i18n("do not contain"))
 		matches = !a->headline().contains(expression());
 	else if (condition() == i18n("equal"))
 		matches = (a->headline() == expression());
-	else if (condition() == i18n("don't equal"))
+	else if (condition() == i18n("do not equal"))
 		matches = (a->headline() != expression());
 	else { // condition() == i18n("match")
 		QRegExp regexp = QRegExp(expression());
