@@ -120,6 +120,7 @@ OnlineStatus::OnlineStatus( StatusType status )
 		break;
 	case Offline:
 		d->description = i18n( "Offline" );
+		break;
 	case Unknown:
 	default:
 		d->description = i18n( "Unknown" );
@@ -146,7 +147,14 @@ OnlineStatus::OnlineStatus( const OnlineStatus &other )
 
 bool OnlineStatus::operator==( const OnlineStatus &other ) const
 {
-	return d->internalStatus == other.d->internalStatus && d->protocol == other.d->protocol;
+	if ( d->internalStatus == other.d->internalStatus && d->protocol == other.d->protocol &&
+	     d->weight == other.d->weight && d->overlayIcons == other.d->overlayIcons &&
+	     d->description == other.d->description )
+	{
+		return true;
+	}
+
+	return false;
 }
 
 bool OnlineStatus::operator!=( const OnlineStatus &other ) const
@@ -228,6 +236,8 @@ QString OnlineStatus::mimeSourceFor( const Contact *contact, int size ) const
 {
 	// figure out what icon we should use for this contact
  	QString iconName = contact->icon();
+	if ( iconName.isNull() )
+		iconName = contact->account()->customIcon();
 	if ( iconName.isNull() )
 		iconName = d->protocolIcon();
 
@@ -242,8 +252,11 @@ QPixmap OnlineStatus::iconFor( const Account *account, int size ) const
 
 QString OnlineStatus::mimeSourceFor( const Account *account, int size ) const
 {
-	//FIXME: support Kopete::Account having knowledge of a custom icon
-	return mimeSource( d->protocolIcon(), size, account->color(), false );
+	QString iconName = account->customIcon();
+	if ( iconName.isNull() )
+		iconName = d->protocolIcon();
+
+	return mimeSource( iconName, size, account->color(), false );
 }
 
 QPixmap OnlineStatus::iconFor( const QString &mimeSource ) const
