@@ -1,7 +1,7 @@
 /*
  *            kPPP: A pppd front end for the KDE project
  *
- * $Id: general.cpp,v 1.98 2004/09/06 15:25:58 mlaurent Exp $
+ * $Id: general.cpp 499014 2006-01-16 20:16:22Z amantia $
  *
  *            Copyright (C) 1997 Bernd Johannes Wuebben
  *                   wuebben@math.cornell.edu
@@ -306,6 +306,10 @@ ModemWidget::ModemWidget(QWidget *parent, bool isnewmodem, const char *name)
 
   static const char *baudrates[] = {
 
+#ifdef B921600
+    "921600",
+#endif
+
 #ifdef B460800
     "460800",
 #endif
@@ -403,7 +407,7 @@ ModemWidget::ModemWidget(QWidget *parent, bool isnewmodem, const char *name)
   }
 
   for(int i=0; i <= flowcontrol->count()-1; i++)
-    if(gpppdata.flowcontrol() == flowcontrol->text(i))
+    if(gpppdata.flowcontrol() == flowListItem[i])
       flowcontrol->setCurrentItem(i);
 
 	//set the modem speed
