@@ -15,13 +15,13 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
 #ifndef FINDNIC_H
 #define FINDNIC_H
 
-#include <qlist.h>
+#include <qptrlist.h>
 #include <qstring.h>
 
 #include <sys/types.h>
@@ -31,13 +31,39 @@
 struct MyNIC
 {
    QString name;
-   struct sockaddr_in addr;
-   struct sockaddr_in netmask;
+   QString addr;
+   QString netmask;
+   QString state;
+   QString type;
 };
 
-typedef QList<MyNIC> NICList;
+struct LisaConfigInfo
+{
+   LisaConfigInfo();
+   void clear();
+   QString pingAddresses;
+   QString broadcastNetwork;
+   QString allowedAddresses;
+   int secondWait;
+   bool secondScan;
+   int firstWait;
+   int maxPingsAtOnce;
+   int updatePeriod;
+   bool useNmblookup;
+   bool unnamedHosts;
+};
 
+
+typedef QPtrList<MyNIC> NICList;
+
+//some plain C-like helper functions
+
+///Return a list with all NIC, which are up and broadcast-able
 NICList* findNICs();
+///Enter some settings into lci which might be appropriate for nic
+void suggestSettingsForNic(MyNIC* nic, LisaConfigInfo& lci);
+
+void suggestSettingsForAddress(const QString& addrMask, LisaConfigInfo& lci);
 
 #endif
 
